@@ -330,12 +330,21 @@ tb_int_t xm_libc_setbyte(lua_State *lua);
 
 // the tty functions
 tb_int_t xm_tty_term_mode(lua_State *lua);
+tb_int_t xm_tty_session_id(lua_State *lua);
 
 // the package functions
 tb_int_t xm_package_loadxmi(lua_State *lua);
 
-// the utils functions
-tb_int_t xm_utils_bin2c(lua_State *lua);
+// the binutils functions
+tb_int_t xm_binutils_bin2c(lua_State *lua);
+tb_int_t xm_binutils_bin2coff(lua_State *lua);
+tb_int_t xm_binutils_bin2macho(lua_State *lua);
+tb_int_t xm_binutils_bin2elf(lua_State *lua);
+tb_int_t xm_binutils_readsyms(lua_State *lua);
+tb_int_t xm_binutils_deplibs(lua_State *lua);
+tb_int_t xm_binutils_rpath_list(lua_State *lua);
+tb_int_t xm_binutils_rpath_clean(lua_State *lua);
+tb_int_t xm_binutils_extractlib(lua_State *lua);
 
 #ifdef XM_CONFIG_API_HAVE_CURSES
 // register curses functions
@@ -643,6 +652,7 @@ static luaL_Reg const g_libc_functions[] = {
 // the tty functions
 static luaL_Reg const g_tty_functions[] = {
     { "term_mode", xm_tty_term_mode },
+    { "session_id", xm_tty_session_id },
     { tb_null, tb_null },
 };
 
@@ -652,9 +662,17 @@ static luaL_Reg const g_package_functions[] = {
     { tb_null, tb_null },
 };
 
-// the utils functions
-static luaL_Reg const g_utils_functions[] = {
-    { "bin2c", xm_utils_bin2c },
+// the binutils functions
+static luaL_Reg const g_binutils_functions[] = {
+    { "bin2c", xm_binutils_bin2c },
+    { "bin2coff", xm_binutils_bin2coff },
+    { "bin2macho", xm_binutils_bin2macho },
+    { "bin2elf", xm_binutils_bin2elf },
+    { "readsyms", xm_binutils_readsyms },
+    { "deplibs", xm_binutils_deplibs },
+    { "rpath_list", xm_binutils_rpath_list },
+    { "rpath_clean", xm_binutils_rpath_clean },
+    { "extractlib", xm_binutils_extractlib },
     { tb_null, tb_null },
 };
 
@@ -702,9 +720,8 @@ static lua_State *g_lua = tb_null;
 
 // the xmake script files data
 #ifdef XM_EMBED_ENABLE
-static tb_byte_t g_xmake_xmz_data[] = {
-#include "xmake.xmz.h"
-};
+extern tb_byte_t _binary_xmake_xmz_start[];
+extern tb_byte_t _binary_xmake_xmz_end[];
 #endif
 
 /* //////////////////////////////////////////////////////////////////////////////////////
@@ -1389,8 +1406,8 @@ static tb_bool_t xm_engine_extract_programfiles_impl(xm_engine_t *engine,
 static tb_bool_t xm_engine_extract_programfiles(xm_engine_t *engine, tb_char_t const *programdir) {
     tb_file_info_t info = { 0 };
     if (!tb_file_info(programdir, &info)) {
-        tb_byte_t const *data = g_xmake_xmz_data;
-        tb_size_t size = sizeof(g_xmake_xmz_data);
+        tb_byte_t const *data = _binary_xmake_xmz_start;
+        tb_size_t size = _binary_xmake_xmz_end - _binary_xmake_xmz_start;
         if (!xm_engine_extract_programfiles_impl(engine, programdir, data, size)) {
             return tb_false;
         }
@@ -1555,8 +1572,8 @@ xm_engine_ref_t xm_engine_init(tb_char_t const *name, xm_engine_lni_initalizer_c
         // bind package functions
         xm_lua_register(engine->lua, "package", g_package_functions);
 
-        // bind utils functions
-        xm_lua_register(engine->lua, "utils", g_utils_functions);
+        // bind binutils functions
+        xm_lua_register(engine->lua, "binutils", g_binutils_functions);
 
         // bind thread functions
         xm_lua_register(engine->lua, "thread", g_thread_functions);
