@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "mkdir"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "mkdir"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -33,21 +33,20 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_os_mkdir(lua_State* lua)
-{
-    // check
+tb_int_t xm_os_mkdir(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // get the path
-    tb_char_t const* path = luaL_checkstring(lua, 1);
+    tb_char_t const *path = luaL_checkstring(lua, 1);
     tb_check_return_val(path, 0);
 
     // os.mkdir(path)
-    tb_file_info_t info = {0};
-    if (!tb_file_info(path, &info) || (info.type != TB_FILE_TYPE_DIRECTORY))
+    tb_file_info_t info = { 0 };
+    if (!tb_file_info(path, &info) || (info.type != TB_FILE_TYPE_DIRECTORY)) {
         lua_pushboolean(lua, tb_directory_create(path));
-    else lua_pushboolean(lua, tb_true);
+    } else {
+        lua_pushboolean(lua, tb_true);
+    }
 
-    // ok
     return 1;
 }
