@@ -22,27 +22,25 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "readlink"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "readlink"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
  */
 #include "prefix.h"
 #ifndef TB_CONFIG_OS_WINDOWS
-#   include <unistd.h>
+#include <unistd.h>
 #endif
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_os_readlink(lua_State* lua)
-{
-    // check
+tb_int_t xm_os_readlink(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // get the path
-    tb_char_t const* path = luaL_checkstring(lua, 1);
+    tb_char_t const *path = luaL_checkstring(lua, 1);
     tb_check_return_val(path, 0);
 
     // is link?
@@ -51,30 +49,26 @@ tb_int_t xm_os_readlink(lua_State* lua)
 #else
     tb_char_t srcpath[TB_PATH_MAXN];
     tb_long_t size = readlink(path, srcpath, TB_PATH_MAXN);
-    if (size == TB_PATH_MAXN)
-    {
-        tb_size_t  maxn = TB_PATH_MAXN * 2;
-        tb_char_t* data = (tb_char_t*)tb_malloc(maxn);
-        if (data)
-        {
+    if (size == TB_PATH_MAXN) {
+        tb_size_t maxn = TB_PATH_MAXN * 2;
+        tb_char_t *data = (tb_char_t *)tb_malloc(maxn);
+        if (data) {
             tb_long_t size = readlink(path, data, maxn);
-            if (size > 0 && size < maxn)
-            {
+            if (size > 0 && size < maxn) {
                 data[size] = '\0';
                 lua_pushstring(lua, data);
+            } else {
+                lua_pushnil(lua);
             }
-            else lua_pushnil(lua);
             tb_free(data);
         }
-    }
-    else if (size >= 0 && size < TB_PATH_MAXN)
-    {
+    } else if (size >= 0 && size < TB_PATH_MAXN) {
         srcpath[size] = '\0';
         lua_pushstring(lua, srcpath);
+    } else {
+        lua_pushnil(lua);
     }
-    else lua_pushnil(lua);
 #endif
 
-    // ok
     return 1;
 }
