@@ -12,7 +12,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright (C) 2015-present, TBOOX Open Source Group.
+ * Copyright (C) 2015-present, Xmake Open Source Community.
  *
  * @author      ruki
  * @file        tmpdir.c
@@ -22,8 +22,8 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * trace
  */
-#define TB_TRACE_MODULE_NAME                "tmpdir"
-#define TB_TRACE_MODULE_DEBUG               (0)
+#define TB_TRACE_MODULE_NAME "tmpdir"
+#define TB_TRACE_MODULE_DEBUG (0)
 
 /* //////////////////////////////////////////////////////////////////////////////////////
  * includes
@@ -33,14 +33,15 @@
 /* //////////////////////////////////////////////////////////////////////////////////////
  * implementation
  */
-tb_int_t xm_os_tmpdir(lua_State* lua)
-{
-    // check
+tb_int_t xm_os_tmpdir(lua_State *lua) {
     tb_assert_and_check_return_val(lua, 0);
 
     // os.tmpdir()
     tb_char_t path[TB_PATH_MAXN];
-    if (tb_directory_temporary(path, sizeof(path))) lua_pushstring(lua, path);
-    else lua_pushnil(lua);
+    if (tb_directory_temporary(path, sizeof(path))) {
+        lua_pushstring(lua, path);
+    } else {
+        lua_pushnil(lua);
+    }
     return 1;
 }
