@@ -1,11 +1,7 @@
--- project
 set_project("xmake")
-
--- version
-set_version("3.0.5", {build = "%Y%m%d"})
-
--- set xmake min version
-set_xmakever("2.8.5")
+set_xmakever("3.0.5")
+set_policy("build.progress_style", "multirow")
+set_version("3.0.6", {build = "%Y%m%d"})
 
 -- set all warnings as errors
 set_warnings("all", "error")
@@ -28,6 +24,12 @@ add_cxflags("-Wno-error=deprecated-declarations", "-fno-strict-aliasing", "-Wno-
 -- add definitions
 add_defines("_GNU_SOURCE=1", "_FILE_OFFSET_BITS=64", "_LARGEFILE_SOURCE")
 
+-- ensure POSIX/XOPEN features are available on Solaris (for setenv, unsetenv, clock_gettime, etc.)
+-- _XOPEN_SOURCE=600 implicitly sets _POSIX_C_SOURCE=200112L
+if is_plat("solaris") then
+    add_defines("_XOPEN_SOURCE=600")
+end
+
 -- add vectorexts
 --[[
 if is_arch("x86", "x64", "i386", "x86_64") then
