@@ -1,7 +1,7 @@
 #!/bin/sh
 
 set_project "xmake"
-set_version "3.0.5" "%Y%m%d"
+set_version "3.0.6" "%Y%m%d"
 
 # set warning all
 set_warnings "all"
@@ -12,6 +12,12 @@ set_languages "c99"
 # add definitions
 add_defines "_GNU_SOURCE=1"  "_FILE_OFFSET_BITS=64"  "_LARGEFILE_SOURCE"
 
+# ensure POSIX/XOPEN features are available on Solaris (for setenv, unsetenv, clock_gettime, etc.)
+# _XOPEN_SOURCE=600 implicitly sets _POSIX_C_SOURCE=200112L
+if is_plat "solaris"; then
+    add_defines "_XOPEN_SOURCE=600"
+fi
+
 # disable some compiler errors
 if is_plat "macosx"; then
     add_cxflags "-Wno-error=deprecated-declarations" "-fno-strict-aliasing" "-Wno-error=nullability-completeness" "-Wno-error=parentheses-equality"
