@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        main.lua
@@ -20,8 +20,15 @@
 
 -- imports
 import("core.base.option")
+import("core.base.hashset")
 
 -- main entry
 function main()
-    import(option.get("format") or "local")()
+    local format = option.get("format") or "local"
+    local maps = hashset.from({"local", "remote", "localpkg"})
+    if maps:has(format) then
+        import(format)()
+    else
+        raise("invalid package format: %s", format or "missing")
+    end
 end
