@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        main.lua
@@ -31,6 +31,7 @@ import("private.action.run.runenvs")
 import("private.service.remote_build.action", {alias = "remote_build_action"})
 import("actions.build.main", {rootdir = os.programdir(), alias = "build_action"})
 import("utils.progress")
+import("private.utils.target", {alias = "target_utils"})
 
 -- test target
 function _do_test_target(target, opt)
@@ -61,21 +62,28 @@ function _do_test_target(target, opt)
     local logname = opt.name:gsub("[/\\>=<|%*]", "_")
     local outfile = path.absolute(path.join(autogendir, logname .. ".out"))
     local errfile = path.absolute(path.join(autogendir, logname .. ".err"))
-    os.tryrm(outfile)
-    os.tryrm(errfile)
+    if opt.realtime_output then
+        outfile = nil
+        errfile = nil
+        assert(not opt.pass_outputs and not opt.fail_outputs, "add_tests(%s): we cannot check pass_outputs/fail_outputs in real output mode", opt.name)
+    else
+        os.tryrm(outfile)
+        os.tryrm(errfile)
+    end
     os.mkdir(autogendir)
+    local should_fail = opt.should_fail or false
     local run_timeout = opt.run_timeout
     local ok, syserrors = os.execv(targetfile, runargs, {try = true, timeout = run_timeout,
         curdir = rundir, envs = envs, stdout = outfile, stderr = errfile})
-    local outdata = os.isfile(outfile) and io.readfile(outfile) or ""
-    local errdata = os.isfile(errfile) and io.readfile(errfile) or ""
+    local outdata = (outfile and os.isfile(outfile)) and io.readfile(outfile) or ""
+    local errdata = (errfile and os.isfile(errfile)) and io.readfile(errfile) or ""
     if outdata and #outdata > 0 then
         opt.stdout = outdata
     end
     if errdata and #errdata > 0 then
         opt.stderr = errdata
     end
-    if opt.trim_output then
+    if opt.trim_output and outdata then
         outdata = outdata:trim()
     end
     if ok ~= 0 then
@@ -91,11 +99,15 @@ function _do_test_target(target, opt)
             end
         end
     end
-    os.tryrm(outfile)
-    os.tryrm(errfile)
+    if outfile then
+        os.tryrm(outfile)
+    end
+    if errfile then
+        os.tryrm(errfile)
+    end
 
+    local passed
     if ok == 0 then
-        local passed
         local pass_outputs = table.wrap(opt.pass_outputs)
         local fail_outputs = table.wrap(opt.fail_outputs)
         for _, pass_output in ipairs(pass_outputs) do
@@ -164,15 +176,28 @@ function _do_test_target(target, opt)
                 end
             end
         end
-        if errors and #errors > 0 then
-            opt.errors = errors
-        end
-        return passed
     end
+
+    if should_fail then
+        if not passed then
+            passed = true
+            errors = nil -- clear errors, since failure was expected
+        else
+            passed = false
+            local extra_info = string.format("Test %s unexpectedly passed (should fail)", opt.name)
+            if errors and #errors > 0 then
+                errors = errors .. "\n" .. extra_info
+            else
+                errors = extra_info
+            end
+        end
+    end
+
     if errors and #errors > 0 then
         opt.errors = errors
     end
-    return false
+
+    return passed
 end
 
 -- test target
@@ -286,6 +311,10 @@ function _run_tests(tests)
         return
     end
 
+    -- temporarily switch to scroll mode to avoid progress refresh interference with test output
+    -- @see https://github.com/xmake-io/xmake/issues/7045
+    progress.set_style("scroll")
+
     -- do test
     local spent = os.mclock()
     print("running tests ...")
@@ -309,6 +338,7 @@ function _run_tests(tests)
                 name = testinfo.name,
                 passed = passed,
                 spent = spent,
+                should_fail = testinfo.should_fail or false,
                 stdout = testinfo.stdout,
                 stderr = testinfo.stderr,
                 errors = testinfo.errors})
@@ -326,29 +356,101 @@ function _run_tests(tests)
         end
     end, {total = #ordertests,
           comax = jobs,
-          isolate = true})
+          isolate = true,
+          progress_refresh = true})
+
+    -- restore the original progress style
+    progress.restore_style()
 
     -- generate report
     spent = os.mclock() - spent
     local passed_rate = math.floor(report.passed * 100 / report.total)
+
+    local failed_tests = {}
+    local expected_failures = {}
+    local unexpected_passes = {}
+
     print("")
     print("report of tests:")
     for idx, testinfo in ipairs(report.tests) do
-        local status_color = testinfo.passed and "${color.success}" or "${color.failure}"
-        local progress_format = status_color .. theme.get("text.build.progress_format") .. ":${clear} "
+        -- Result label and color logic
+        local result_label
+        local result_color
+
+        if testinfo.should_fail then
+            if testinfo.passed then
+                table.insert(expected_failures, testinfo.name)
+                result_label = "expected failure"
+                result_color = "${color.warning}"
+            else
+                table.insert(unexpected_passes, testinfo.name)
+                result_label = "unexpected pass"
+                result_color = "${color.failure}"
+            end
+        else
+            if testinfo.passed then
+                result_label = "passed"
+                result_color = "${color.success}"
+            else
+                result_label = "failed"
+                result_color = "${color.failure}"
+                table.insert(failed_tests, testinfo.name)
+            end
+        end
+
+        local progress_format = result_color .. theme.get("text.build.progress_format") .. ":${clear} "
         if option.get("verbose") or option.get("diagnosis") then
             progress_format = progress_format .. "${dim}"
         end
+
+        -- Build aligned output line
         local padding = maxwidth - #testinfo.name
+        local filler = string.rep(".", padding)
         local progress_percent = math.floor(idx * 100 / #report.tests)
-        cprint(progress_format .. "%s%s .................................... " .. status_color .. "%s${clear} ${bright}%0.3fs",
-            progress_percent, testinfo.name, (" "):rep(padding), testinfo.passed and "passed" or "failed", testinfo.spent / 1000)
+        cprint(progress_format .. "%s %s " .. result_color .. "%s${clear} ${bright}%0.3fs",
+            progress_percent, testinfo.name, filler, result_label, testinfo.spent / 1000)
+
         _show_output(testinfo, "stdout")
         _show_output(testinfo, "stderr")
         _show_output(testinfo, "errors")
     end
-    cprint("${color.success}%d%%${clear} tests passed, ${color.failure}%d${clear} tests failed out of ${bright}%d${clear}, spent ${bright}%0.3fs",
-        passed_rate, report.total - report.passed, report.total, spent / 1000)
+
+    -- Print the summary
+    if #failed_tests > 0 or #expected_failures > 0 or #unexpected_passes > 0 then
+        cprint("\nDetailed summary:")
+    end
+    if #failed_tests > 0 then
+        cprint("${color.failure}Failed tests:${clear}")
+        for _, name in ipairs(failed_tests) do
+            print(" - " .. name)
+        end
+    end
+
+    if #unexpected_passes > 0 then
+        cprint("${color.failure}Unexpected passes:${clear}")
+        for _, name in ipairs(unexpected_passes) do
+            print(" - " .. name)
+        end
+    end
+
+    if #expected_failures > 0 then
+        cprint("${color.warning}Expected failures:${clear}")
+        for _, name in ipairs(expected_failures) do
+            print(" - " .. name)
+        end
+    end
+
+    local summary = string.format("\n${color.success}%d%%%%${clear} tests passed, ${color.failure}%d${clear} test(s) failed", passed_rate, #failed_tests)
+    if #unexpected_passes > 0 then
+        summary = summary .. string.format(", ${color.failure}%d${clear} unexpected pass(es)", #unexpected_passes)
+    end
+    if #expected_failures > 0 then
+        summary = summary .. string.format(", ${color.warning}%d${clear} expected failure(s)", #expected_failures)
+    end
+
+    summary = summary .. string.format(" out of ${bright}%d${clear}, spent ${bright}%0.3fs", report.total, spent / 1000)
+    cprint(summary)
+
     local return_zero = project.policy("test.return_zero_on_failure")
     if not return_zero and report.passed < report.total then
         raise()
@@ -421,6 +523,7 @@ function get_tests()
                     if extra.packages then
                         target_new:add("packages", extra.packages)
                     end
+                    target_utils.config_target(target_new)
                     testinfo.target = target_new
                 end
             end
@@ -472,7 +575,7 @@ function main()
     -- build targets with the given tests first
     local targetnames = {}
     for _, testinfo in table.orderpairs(tests) do
-        local targetname = testinfo.target:name()
+        local targetname = testinfo.target:fullname()
         if testinfo.build_should_pass then
             local passed, errors = _try_build_target(targetname)
             testinfo.passed = passed
