@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        main.lua
@@ -238,7 +238,7 @@ function _install(sourcedir)
     if option.get("verbose") then
         install_task()
     else
-        runjobs("update/install", install_task, {progress = true})
+        runjobs("update/install", install_task, {waiting_indicator = true})
     end
 end
 
@@ -339,7 +339,7 @@ test -f "%s" && source "%s"
                     file = file .. "\n"
                 end
             end
-            file = file .. "# >>> xmake >>>\n" .. command .. "\n# <<< xmake <<<"
+            file = file .. "# >>> xmake >>>\n" .. command .. "\n# <<< xmake <<<\n"
             io.writefile(target, file)
             return true
         end,
@@ -512,7 +512,7 @@ function main()
     if option.get("verbose") then
         download_task()
     else
-        runjobs("update/download", download_task, {progress = true})
+        runjobs("update/download", download_task, {waiting_indicator = true})
     end
 
     -- leave environment
