@@ -964,6 +964,24 @@ function project.policy(name)
     return policy.check(name, policies and policies[name])
 end
 
+-- set the project policy in memory
+function project.policy_set(name, value)
+    -- get current policies from cache or initialize
+    local policies = project._memcache():get("policies")
+    if not policies then
+        -- force initialization by calling policy() once
+        project.policy(name)
+        policies = project._memcache():get("policies")
+    end
+    policies = policies or {}
+    
+    -- set the policy value
+    policies[name] = value
+    
+    -- update cache
+    project._memcache():set("policies", policies)
+end
+
 -- project has been loaded?
 function project.is_loaded()
     return project._memcache():get("targets_loaded")
@@ -1138,14 +1156,17 @@ function project.requireconfs_str()
         local requires_extra = project._memcache():get("requires_extra")
         local sync_requires_to_deps = project._memcache():get("package.sync_requires_to_deps")
         if requires_str and not sync_requires_to_deps then
+            local package_utils = project._package_utils
+            if package_utils == nil then
+                package_utils = sandbox_module.import("private.utils.package", {anonymous = true})
+                project._package_utils = package_utils
+            end
             requires_extra = requires_extra and table.wrap(requires_extra) or {}
             requireconfs_str = requireconfs_str and table.wrap(requireconfs_str) or {}
             requireconfs_extra = requireconfs_extra and table.wrap(requireconfs_extra) or {}
             for _, require_str in ipairs(table.wrap(requires_str)) do
                 if not require_str:find("::", 1, true) then
-                    local splitinfo = require_str:split("%s")
-                    local packagename = splitinfo[1]
-                    local packageversion = splitinfo[2]
+                    local packagename, packageversion = package_utils.parse_requirestr(require_str)
                     local requireconf_str = "**." .. packagename
                     local requireconf_extra = table.clone(requires_extra[require_str])
                     if requireconf_extra then
@@ -1153,7 +1174,7 @@ function project.requireconfs_str()
                     end
                     if packageversion then
                         requireconf_extra = requireconf_extra or {configs = {}}
-                        requireconf_extra.configs.version = packageversion
+                        requireconf_extra.version = packageversion
                     end
                     if requireconf_extra then
                         requireconf_extra.override = true
@@ -1207,9 +1228,14 @@ end
 -- get the given toolchain
 function project.toolchain(name, opt)
     opt = opt or {}
-    local toolchain_name = toolchain.parsename(name) -- we need to ignore `@packagename`
+    local parseinfo = toolchain.parsename(name) -- we need to ignore `@packagename`
+    local toolchain_name = parseinfo.name
     local info = project._toolchains()[toolchain_name]
     if info == nil and opt.namespace then
+        local requirestr = parseinfo.requirestr
+        if requirestr then
+            toolchain_name = toolchain_name .. "[" .. requirestr .. "]"
+        end
         info = project._toolchains()[opt.namespace .. "::" .. toolchain_name]
     end
     if info then
@@ -1271,6 +1297,11 @@ end
 -- get the project menu
 function project.menu()
 
+    -- we cannot only get it in main thread
+    if not xmake.in_main_thread() then
+        return {}
+    end
+
     -- attempt to load options from the project file
     local options = nil
     local errors = nil
