@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        remove_files.lua
@@ -25,6 +25,10 @@ import("core.base.option")
 function main(filedirs, opt)
     opt = opt or {}
     for _, filedir in ipairs(filedirs) do
-        os.tryrm(filedir, {emptydirs = option.get("all") or opt.emptydir})
+        -- os.exists will return false if symlink -> not found, but we need still remove this symlink
+        if os.exists(filedir) or os.islink(filedir) then
+            -- we cannot use os.tryrm, because we need raise exception if remove failed with `uninstall --admin`
+            os.rm(filedir, {emptydirs = option.get("all") or opt.emptydir})
+        end
     end
 end
