@@ -116,6 +116,10 @@ rule("qt.widgetapp")
     after_install("windows", "install.windows")
     after_install("mingw", "install.mingw")
 
+    -- install application for xpack
+    on_installcmd("installcmd")
+    on_uninstallcmd("uninstallcmd")
+
 -- define rule: qt static widgetapp
 rule("qt.widgetapp_static")
     add_deps("qt.ui", "qt.moc", "qt._wasm_app", "qt.qrc", "qt.ts")
@@ -144,6 +148,10 @@ rule("qt.widgetapp_static")
     after_install("windows", "install.windows")
     after_install("mingw", "install.mingw")
 
+    -- install application for xpack
+    on_installcmd("installcmd")
+    on_uninstallcmd("uninstallcmd")
+
 -- define rule: qt quickapp
 rule("qt.quickapp")
     add_deps("qt.qrc", "qt.moc", "qt._wasm_app", "qt.ts")
@@ -166,6 +174,10 @@ rule("qt.quickapp")
     after_install("windows", "install.windows")
     after_install("mingw", "install.mingw")
 
+    -- install application for xpack
+    on_installcmd("installcmd")
+    on_uninstallcmd("uninstallcmd")
+
 -- define rule: qt static quickapp
 rule("qt.quickapp_static")
     add_deps("qt.qrc", "qt.moc", "qt._wasm_app", "qt.ts")
@@ -190,6 +202,10 @@ rule("qt.quickapp_static")
     after_install("windows", "install.windows")
     after_install("mingw", "install.mingw")
 
+    -- install application for xpack
+    on_installcmd("installcmd")
+    on_uninstallcmd("uninstallcmd")
+
 -- define rule: qt qmlplugin
 rule("qt.qmlplugin")
     add_deps("qt.shared", "qt.qmltyperegistrar", "qt.ts")
